summaryrefslogtreecommitdiff
path: root/gpspipe.c
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2006-09-25 18:49:22 +0000
committerGary E. Miller <gem@rellim.com>2006-09-25 18:49:22 +0000
commitc563a5d416599fd5676b11cee32b263f14b5b5b7 (patch)
treeda61b4974fae2736d8fc518f0e69291eeeac0bd7 /gpspipe.c
parent9fd26ad003cbbccc984465e18d97085ec1e8ec0c (diff)
downloadgpsd-c563a5d416599fd5676b11cee32b263f14b5b5b7.tar.gz
ckuethe points out that super-raw is not just SiRF binary.
Diffstat (limited to 'gpspipe.c')
-rw-r--r--gpspipe.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/gpspipe.c b/gpspipe.c
index 98a5422a..290a216d 100644
--- a/gpspipe.c
+++ b/gpspipe.c
@@ -8,7 +8,7 @@
* This will dump the raw NMEA from gpsd to stdout
* gpspipe -r
*
* This will dump the super-raw data (SiRF) from gpsd to stdout
* gpspipe -R
*
* This will dump the GPSD sentences from gpsd to stdout
@@ -98,6 +98,7 @@ static void usage(void) {
"SVN ID: $Id$ \n"
"-h show this help\n"
"-r Dump raw NMEA\n"
+ "-R Dump super-raw mode (gps binary)\n"
"-w Dump gpsd native data\n"
"-t time stamp the data\n"
"-s [serial dev] emulate a 4800bps NMEA GPS on serial port (use with '-r')\n"
@@ -164,6 +165,9 @@ int main( int argc, char **argv) {
if ( dump_super_raw ) {
cstr = "R=2\n";
+ /* super raw overrides NMEA and GPSD modes */
+ bool dump_nmea = false;
+ bool dump_gpsd = false;
} else if ( dump_nmea ) {
if ( dump_gpsd ) {
cstr = "rw\n";
@@ -8,7 +8,7 @@
* gpspipe -r
*
- * This will dump the super-raw data (SiRF) from gpsd to stdout
+ * This will dump the super-raw data (gps binary) from gpsd to stdout
* gpspipe -R
*